pub trait DivRemAssign<Rhs = Self> {
type OutputRem;
// Required method
fn div_rem_assign(&mut self, rhs: Rhs) -> Self::OutputRem;
}Expand description
Compute quotient inplace and return remainder at the same time.
Examples
use dashu_base::DivRemAssign;
let mut n = 23;
let r = n.div_rem_assign(10);
assert!(n == 2 && r == 3);Required Associated Types
Required Methods
Sourcefn div_rem_assign(&mut self, rhs: Rhs) -> Self::OutputRem
fn div_rem_assign(&mut self, rhs: Rhs) -> Self::OutputRem
Divide self by rhs in place, storing the quotient in self and returning the remainder.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".